@@ -8,4 +8,6 @@ PrintNCBI2RInfo<-function()
    msg5<-temp$package.web
    msg6<-"Please read the usage guidelines on the website."
    writeLines(c(msg1,msg2,msg3,msg4,msg5,msg6))
+   writeLines("now checking if you have the latest version")
+   UpdateCheck()
    }
\ No newline at end of file
